#ifndef __PYX_HAVE__scipy__special___ellip_harm_2
#define __PYX_HAVE__scipy__special___ellip_harm_2


#ifndef __PYX_HAVE_API__scipy__special___ellip_harm_2

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#ifndef DL_IMPORT
  #define DL_IMPORT(_T) _T
#endif

__PYX_EXTERN_C DL_IMPORT(int) wrap_PyUFunc_getfperr(void);

#endif /* !__PYX_HAVE_API__scipy__special___ellip_harm_2 */

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_ellip_harm_2(void);
#else
PyMODINIT_FUNC PyInit__ellip_harm_2(void);
#endif

#endif /* !__PYX_HAVE__scipy__special___ellip_harm_2 */
